@@ -1,11 +1,13 @@
 import streamlit as st
 from streamlit_tags import st_tags
 from keytotext import pipeline
+import os
+
+os.environ['TOKENIZERS_PARALLELISM'] = 'false'
+
 
 st.set_page_config(
     page_title="Text Generation Using Keywords",
-    #layout="wide",
-    #initial_sidebar_state="expanded",
 )
 
 
@@ -30,7 +32,7 @@ def display():
                    step=1)
 
     model = st.selectbox(label="Select the model you would like to run",
-                         options=['k2t', 'k2t-base', 'k2t-tiny'])
+                         options=['k2t', 'k2t-base'])
 
     keywords = st_tags(label='## Enter Keywords:',
                        text='Press enter to add more',
