@@ -84,12 +84,6 @@ SUPPORTED_TASKS = {
             "model": "gagan3012/k2t",
         },
     },
-    "k2t-tiny": {
-        "impl": K2TPipeline,
-        "default": {
-            "model": "gagan3012/k2t-tiny",
-        },
-    },
     "k2t-base": {
         "impl": K2TPipeline,
         "default": {
